import{f as l,eG as o,eN as f}from"./outputWidgets.8f35e76b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a2f579c5-6c69-4395-a35f-ac4ac3c49435",e._sentryDebugIdIdentifier="sentry-dbid-a2f579c5-6c69-4395-a35f-ac4ac3c49435")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(c){return Object.getOwnPropertyDescriptor(r,c).enumerable}))),n.forEach(function(c){u(e,c,r[c])})}return e}function u(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var a=function(t,r){var n=i({},t,r.attrs);return l(o,i({},n,{icon:f}),null)};a.displayName="CloseCircleOutlined";a.inheritAttrs=!1;const d=a;export{d as C};
//# sourceMappingURL=CloseCircleOutlined.11827823.js.map
