import{v as t,b as s,eu as c}from"./outputWidgets.8f35e76b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cfc2cb98-70d6-48f1-a886-0f9d211c096d",e._sentryDebugIdIdentifier="sentry-dbid-cfc2cb98-70d6-48f1-a886-0f9d211c096d")}catch{}})();const d={},o={class:"organization-settings"};function r(e,n){return s(),c("div",o,"Organization settings")}const f=t(d,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.065739eb.js.map
