import{U as s}from"./outputWidgets.8f35e76b.js";import{c as i,d as f}from"./index.5bde41da.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="09a651f1-5a3c-41f5-8a0b-a444f5fcca9b",e._sentryDebugIdIdentifier="sentry-dbid-09a651f1-5a3c-41f5-8a0b-a444f5fcca9b")}catch{}})();const{DatePicker:n,WeekPicker:a,MonthPicker:r,YearPicker:d,TimePicker:m,QuarterPicker:t,RangePicker:o}=i(f),y=s(n,{WeekPicker:a,MonthPicker:r,YearPicker:d,RangePicker:o,TimePicker:m,QuarterPicker:t,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(a.name,a),e.component(t.name,t),e)});export{y as D,r as M,t as Q,o as R,a as W};
//# sourceMappingURL=dayjs.ff950c3d.js.map
