import{d as g,eI as b,r as y,I as v,b as h,eu as k,f as m,u as t,v as w}from"./outputWidgets.8f35e76b.js";import{g as I}from"./api.43bf4307.js";import{a as p}from"./asyncComputed.b2c7682e.js";import{P as H}from"./PlayerNavbar.2eec09a3.js";import{H as D}from"./HomeContent.685266e7.js";import{u as s}from"./index.f6ce12ef.js";import"./runnerData.6e315e3e.js";import"./url.99f1e379.js";import"./PhKanban.vue.c924b5ce.js";import"./PhSignOut.vue.2543e2c9.js";import"./Text.cb1b4ad4.js";import"./index.8416d0cc.js";import"./Link.453a8ef1.js";import"./Paragraph.5b35e944.js";import"./Title.984d5105.js";import"./index.31b873d2.js";import"./PhArrowSquareOut.vue.eae4d0a1.js";import"./index.d94e180a.js";import"./Card.05a66930.js";import"./index.1b34424f.js";import"./TabPane.385f8290.js";import"./hasIn.38270313.js";import"./index.30032ec4.js";import"./pubsub.aac2ae7d.js";import"./fetch.5a9928e7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="f1a895eb-d809-4264-a062-4a01107c4a86",o._sentryDebugIdIdentifier="sentry-dbid-f1a895eb-d809-4264-a062-4a01107c4a86")}catch{}})();const x={class:"page"},C=g({__name:"Home",setup(o){const e=b(),r=y(s.getUser()),{result:c,refetch:u}=p(async()=>(await s.allow("kanban")).status==="ALLOWED");v(r,()=>u());const l=({path:a})=>{e.push({name:"form",params:{path:a.split("/")}})},{result:n,loading:d}=p(I),f=a=>{e.push({path:`/${a}`})},_=()=>{s.removeUser(),e.push({name:"playerHome"})};return(a,L)=>{var i;return h(),k("div",x,[m(H,{"runner-data":t(n),"is-kanban-visible":t(c)||!1,"user-email":(i=r.value)==null?void 0:i.claims.email,onNavigate:l,onLogout:_},null,8,["runner-data","is-kanban-visible","user-email"]),m(D,{workspace:t(n),loading:t(d),onFormClick:f},null,8,["workspace","loading"])])}}});const ee=w(C,[["__scopeId","data-v-f12c98c4"]]);export{ee as default};
//# sourceMappingURL=Home.d05d5695.js.map
