import{B as d}from"./BookOutlined.b79ac83a.js";import{d as f,b as a,c as l,w as o,f as c,u as n,dh as u,eu as i,aq as p,aC as y,bE as b}from"./outputWidgets.8f35e76b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="0f687f82-d668-4c25-af58-09d676f23686",t._sentryDebugIdIdentifier="sentry-dbid-0f687f82-d668-4c25-af58-09d676f23686")}catch{}})();const h=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),l(n(b),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[c(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(y,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{h as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.7378a41f.js.map
