import{_ as I}from"./logo.084e5d7c.js";import{v,b as r,eu as p,eE as w,eF as C,e as d,d as k,eI as N,a as D,u as e,c,bf as L,w as t,f as s,aq as l,eD as f,bE as m,cA as S,cw as $,eM as E,eB as V,f7 as z,aC as y,ew as F,dh as R}from"./outputWidgets.8f35e76b.js";import{b as h,c as T}from"./router.eb6cf81e.js";import{a as q}from"./asyncComputed.b2c7682e.js";import{F as M}from"./PhSignOut.vue.2543e2c9.js";import{A as P}from"./Text.cb1b4ad4.js";import{A as j}from"./index.31b873d2.js";import{B as H,A as O,b as U}from"./index.11f588c6.js";import{B as G}from"./BookOutlined.b79ac83a.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="8b75153b-e5fd-47e9-ae08-56271b010ede",o._sentryDebugIdIdentifier="sentry-dbid-8b75153b-e5fd-47e9-ae08-56271b010ede")}catch{}})();const J={},x=o=>(w("data-v-46e041c1"),o=o(),C(),o),K={class:"logo"},Q=x(()=>d("img",{class:"logo-img",src:I,alt:"Abstra cloud logo"},null,-1)),W=x(()=>d("span",null,"Abstra",-1)),X=[Q,W];function Y(o,a){return r(),p("div",K,X)}const Z=v(J,[["render",Y],["__scopeId","data-v-46e041c1"]]),ee={style:{display:"flex","flex-direction":"column",gap:"10px"}},te={style:{display:"flex",gap:"5px"}},oe=k({__name:"LoginBlock",setup(o){function a(b){const g=b.split("@")[0];return E.exports.kebabCase(g).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const i=N(),{result:n,loading:_,refetch:A}=q(async()=>h.getAuthor());function B(){h.removeAuthor(),T.shutdown(),A(),i.push({name:"login"})}return(b,g)=>{const u=D("router-link");return e(_)?(r(),c(e(L),{key:0})):e(n)?(r(),c(e($),{key:1,placement:"bottomRight"},{content:t(()=>[d("div",ee,[s(e(P),{size:"small",type:"secondary"},{default:t(()=>[l(f(e(n).claims.email),1)]),_:1}),s(e(m),{type:"text",onClick:B},{default:t(()=>[d("div",te,[s(e(M),{size:"20"}),l(" Logout ")])]),_:1})])]),default:t(()=>[s(e(S),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[s(e(j),{shape:"square"},{default:t(()=>[l(f(a(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(m),{key:2},{default:t(()=>[s(u,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),se={class:"extra"},ae=k({__name:"Navbar",props:{breadcrumb:{}},setup(o){return(a,i)=>(r(),c(e(U),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[a.breadcrumb?(r(),c(e(H),{key:0,style:{margin:"0px 50px"}},{default:t(()=>[(r(!0),p(y,null,V(a.breadcrumb,(n,_)=>(r(),c(e(O),{key:_},{default:t(()=>[s(e(z),{to:n.path},{default:t(()=>[l(f(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[s(Z)]),extra:t(()=>[d("div",se,[s(e(m),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[s(e(G))]),default:t(()=>[a.$slots.default?R(a.$slots,"default",{key:0},void 0,!0):(r(),p(y,{key:1},[l("Docs")],64))]),_:3}),s(oe)])]),_:3}))}});const fe=v(ae,[["__scopeId","data-v-31e2a422"]]);export{fe as N};
//# sourceMappingURL=Navbar.c17d3c02.js.map
