import{cu as o}from"./outputWidgets.8f35e76b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b57b878c-9c8e-4403-a681-4f50f6637725",e._sentryDebugIdIdentifier="sentry-dbid-b57b878c-9c8e-4403-a681-4f50f6637725")}catch{}})();const f=(e,r,n)=>{o.error({message:e,description:r,onClick:n})};export{f as p};
//# sourceMappingURL=popupNotifcation.20f659d9.js.map
