import{F as t}from"./Form.357810f8.js";import{b1 as r,cj as n}from"./outputWidgets.8f35e76b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8422951f-bdf5-4514-aa6d-b93458380a9c",e._sentryDebugIdIdentifier="sentry-dbid-8422951f-bdf5-4514-aa6d-b93458380a9c")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.11f203e6.js.map
