import{U as s,f as d,O as p}from"./outputWidgets.8f35e76b.js";import{B as f,b as i}from"./Text.cb1b4ad4.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="fa7a1d7f-a9b8-43cb-864a-3d7c893a5d60",a._sentryDebugIdIdentifier="sentry-dbid-fa7a1d7f-a9b8-43cb-864a-3d7c893a5d60")}catch{}})();const c=()=>p(i(),["component"]),e=(a,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},a),{component:"div"}),o);return d(f,n,t)};e.displayName="ATypographyParagraph";e.inheritAttrs=!1;e.props=c();const g=e;export{g as A};
//# sourceMappingURL=Paragraph.5b35e944.js.map
