import{g as m}from"./api.43bf4307.js";import{P as f}from"./Passwordless.ceae5811.js";import{a as d}from"./asyncComputed.b2c7682e.js";import{W as p}from"./WidgetsFrame.87b1c2ad.js";import{d as u,eI as l,eA as _,b as i,eu as y,e as g,u as a,c as w,w as b,ew as h,f as v,v as I}from"./outputWidgets.8f35e76b.js";import{u as k}from"./index.f6ce12ef.js";import"./runnerData.6e315e3e.js";import"./url.99f1e379.js";import"./index.74670cde.js";import"./PhArrowClockwise.vue.d84d962d.js";import"./CircularLoading.cdfdf5ef.js";import"./pubsub.aac2ae7d.js";import"./fetch.5a9928e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="88c4f013-0a5f-487a-8efc-321bc707a903",e._sentryDebugIdIdentifier="sentry-dbid-88c4f013-0a5f-487a-8efc-321bc707a903")}catch{}})();const x={class:"login"},C=u({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=d(m),c=async()=>{await k.signUp();const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(i(),y("div",null,[g("div",x,[a(o)?(i(),w(p,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:b(()=>[v(f,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):h("",!0)])]))}});const M=I(C,[["__scopeId","data-v-73f41769"]]);export{M as default};
//# sourceMappingURL=Login.39b4c0ba.js.map
