import{eX as t,eY as r}from"./outputWidgets.8f35e76b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9604907e-3d9b-4771-ab19-0a821b328500",e._sentryDebugIdIdentifier="sentry-dbid-9604907e-3d9b-4771-ab19-0a821b328500")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.9ae05ba9.js.map
