import{P as b}from"./PlayerNavbar.2eec09a3.js";import{g as h}from"./api.43bf4307.js";import{a as d}from"./asyncComputed.b2c7682e.js";import{W as v}from"./WidgetsFrame.87b1c2ad.js";import{d as w,r as k,I,eI as D,eA as x,b as p,eu as C,e as o,f as E,u as t,c as N,w as P,ew as V,eD as f,v as A}from"./outputWidgets.8f35e76b.js";import{u as n}from"./index.f6ce12ef.js";import"./PhKanban.vue.c924b5ce.js";import"./PhSignOut.vue.2543e2c9.js";import"./Text.cb1b4ad4.js";import"./index.8416d0cc.js";import"./Link.453a8ef1.js";import"./Paragraph.5b35e944.js";import"./Title.984d5105.js";import"./index.31b873d2.js";import"./runnerData.6e315e3e.js";import"./url.99f1e379.js";import"./pubsub.aac2ae7d.js";import"./fetch.5a9928e7.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new q().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="2578a055-50e2-45e5-b40b-72fa840090ce",a._sentryDebugIdIdentifier="sentry-dbid-2578a055-50e2-45e5-b40b-72fa840090ce")}catch{}})();const B={class:"error"},L={class:"inner-content"},W=w({__name:"Error",setup(a){const r=k(n.getUser()),{result:i,refetch:_}=d(async()=>(await n.allow("kanban")).status==="ALLOWED");I(r,()=>_());const u=D(),g=({path:e})=>{u.push({name:"form",query:c.query,params:{path:e.split("/")}})},c=x(),{result:s}=d(h),y=()=>{n.removeUser(),u.push({name:"playerHome"})},m=()=>{const{status:e}=c.params;switch(e){case"404":return{status:e,message:"Page not found."};case"403":return{status:e,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(e,F)=>{var l;return p(),C("div",null,[o("div",B,[E(b,{"user-email":(l=r.value)==null?void 0:l.claims.email,"is-kanban-visible":t(i)||!1,"runner-data":t(s),onNavigate:g,onLogout:y},null,8,["user-email","is-kanban-visible","runner-data"]),t(s)?(p(),N(v,{key:0,"main-color":t(s).mainColor,theme:t(s).theme,"font-family":t(s).fontFamily,style:{height:"100vh",width:"100%"}},{default:P(()=>[o("div",L,[o("h1",null,f(m().status),1),o("p",null,f(m().message),1)])]),_:1},8,["main-color","theme","font-family"])):V("",!0)])])}}});const q=A(W,[["__scopeId","data-v-98d8191f"]]);export{q as default};
//# sourceMappingURL=Error.52bbfa8b.js.map
