import{u as t,a as u}from"./index.f6ce12ef.js";import{d as l,r as c,b,eu as d,f as n,u as e}from"./outputWidgets.8f35e76b.js";import{g as f}from"./api.43bf4307.js";import{K as y,P as g,L as _}from"./repository.9cc76153.js";import{P as k}from"./PlayerNavbar.2eec09a3.js";import{a as w}from"./asyncComputed.b2c7682e.js";import"./pubsub.aac2ae7d.js";import"./fetch.5a9928e7.js";import"./runnerData.6e315e3e.js";import"./url.99f1e379.js";import"./workspaces.afd4edf2.js";import"./record.56272af3.js";import"./scripts.714861ba.js";import"./envVars.04759b67.js";import"./api.a476abaa.js";import"./index.cf4c23b9.js";import"./metadata.5258e7e7.js";import"./PhCheckCircle.vue.744c2106.js";import"./PhScroll.vue.b0c3dd17.js";import"./PhWebhooksLogo.vue.41e42723.js";import"./forms.8f2b56b4.js";import"./ant-design.5e6d66d7.js";import"./index.01563854.js";import"./Modal.3cec70ce.js";import"./Text.cb1b4ad4.js";import"./index.30032ec4.js";import"./index.1d88a799.js";import"./index.9ae05ba9.js";import"./Paragraph.5b35e944.js";import"./index.8416d0cc.js";import"./Link.453a8ef1.js";import"./Title.984d5105.js";import"./index.85ee2aed.js";import"./CollapsePanel.5542395e.js";import"./index.c56951cc.js";import"./index.fa549dca.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.8a63c284.js";import"./Card.05a66930.js";import"./index.1b34424f.js";import"./TabPane.385f8290.js";import"./hasIn.38270313.js";import"./LoadingOutlined.8ed9851d.js";import"./vuedraggable.umd.6098fdf5.js";import"./index.11f203e6.js";import"./Form.357810f8.js";import"./PhKanban.vue.c924b5ce.js";import"./PhSignOut.vue.2543e2c9.js";import"./index.31b873d2.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="1a221de7-c814-4f6c-9532-bca152570bbe",r._sentryDebugIdIdentifier="sentry-dbid-1a221de7-c814-4f6c-9532-bca152570bbe")}catch{}})();const _r=l({__name:"Kanban",setup(r){const o=new g(t),a=new _("kanban"),m=c(t.getUser()),{result:p}=w(f),s=()=>{t.removeUser(),u.push({name:"playerHome"})};return(v,h)=>{var i;return b(),d("div",null,[n(k,{"runner-data":e(p),"show-kanban":!1,"is-kanban-visible":!1,"user-email":(i=m.value)==null?void 0:i.claims.email,onLogout:s},null,8,["runner-data","user-email"]),n(y,{"kanban-repository":e(o),storage:e(a)},null,8,["kanban-repository","storage"])])}}});export{_r as default};
//# sourceMappingURL=Kanban.36cf2c2b.js.map
